# APIFairy

[![Build Status](https://travis-ci.org/miguelgrinberg/APIFairy.png?branch=master)](https://travis-ci.org/miguelgrinberg/APIFairy)

Resources
---------

- [Documentation](http://apifairy.readthedocs.io/en/latest/)
- [PyPI](https://pypi.python.org/pypi/APIFairy)
- [Change Log](https://github.com/miguelgrinberg/APIFairy/blob/master/CHANGES.md)
